@@ -1,2 +1,2 @@
 from .external_downloader import ExternalDownloader  # noqa ignore=F401
-from .results import SearhResult  # noqa ignore=F401
+from .results import Buttons, SearchResult  # noqa ignore=F401
